@@ -894,9 +894,9 @@ sub search {
         return $self->status(1);
     }
     $self->status and return $self->status;
-    uscan_verbose
-      "Looking at \$base        = $self->{parse_result}->{base} with\n"
-      . "    \$filepattern        = $self->{parse_result}->{filepattern} found\n"
+    uscan_verbose "uscan parser results:\n"
+      . "    \$base               = $self->{parse_result}->{base}\n"
+      . "    \$filepattern        = $self->{parse_result}->{filepattern}\n"
       . "    \$newfile            = $newfile\n"
       . "    \$mangled_newversion = $mangled_newversion\n"
       . "    \$newversion         = $newversion\n"
@@ -1149,7 +1149,10 @@ sub download_file_and_sig {
 
     # 6.1 download tarball
     my $download_available = 0;
-    my $upstream_base      = basename($self->upstream_url);
+    my $upstream_base
+      = ($self->mode ne 'git')
+      ? basename($self->upstream_url)
+      : $self->upstream_url;
     $self->signature_available(0);
     my $sigfile;
     my $sigfile_base = $self->newfile_base;
