@@ -393,7 +393,11 @@ $message = getmessage()
 
 if ($release || $changelog_info) {
     require Dpkg::Changelog::Parse;
-    my $log = Dpkg::Changelog::Parse::changelog_parse(file => $changelog);
+    my $log = Dpkg::Changelog::Parse::changelog_parse(
+        filename => $changelog,
+        # XXX: Backwards compatibility, remove after dpkg 1.24.0.
+        file => $changelog
+    );
     if ($release) {
         if ($log->{Distribution} =~ /UNRELEASED/) {
             die
@@ -453,6 +457,10 @@ sub getprog {
             return "darcs";
         }
     }
+    if (-e ".git") {
+# With certain forms of git checkouts, .git can be a file instead of a directory
+        return "git";
+    }
     if (-d ".svn") {
         return "svn";
     }
@@ -472,10 +480,6 @@ sub getprog {
     if (-d ".bzr") {
         return "bzr";
     }
-    if (-e ".git") {
-# With certain forms of git checkouts, .git can be a file instead of a directory
-        return "git";
-    }
     if (-d ".hg") {
         return "hg";
     }
